@@ -65,8 +65,8 @@ void blocks_etc_drag(magic_api * api, int which, SDL_Surface * canvas,
                      SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect);
 void blocks_etc_click(magic_api * api, int which, int mode,
                       SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect);
-void blocks_etc_release(magic_api * api, int which,
-                        SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect);
+void blocks_etc_release(magic_api * api, int which, SDL_Surface * canvas,
+                        SDL_Surface * last, int x, int y, SDL_Rect * update_rect);
 void blocks_etc_shutdown(magic_api * api);
 void blocks_etc_set_color(magic_api * api, int which, SDL_Surface * canvas,
                           SDL_Surface * last, Uint8 r, Uint8 g, Uint8 b, SDL_Rect * update_rect);
@@ -76,8 +76,8 @@ void blocks_etc_switchout(magic_api * api, int which, int mode, SDL_Surface * ca
 int blocks_etc_modes(magic_api * api, int which);
 Uint8 blocks_etc_accepted_sizes(magic_api * api, int which, int mode);
 Uint8 blocks_etc_default_size(magic_api * api, int which, int mode);
-void blocks_etc_set_size(magic_api * api, int which, int mode, SDL_Surface * canvas, SDL_Surface * last, Uint8 size,
-                         SDL_Rect * update_rect);
+void blocks_etc_set_size(magic_api * api, int which, int mode,
+                         SDL_Surface * canvas, SDL_Surface * last, Uint8 size, SDL_Rect * update_rect);
 
 
 
@@ -419,10 +419,12 @@ void blocks_etc_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 }
 
 // Record the color from Tux Paint:
-void blocks_etc_set_color(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                          SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
-                          Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED,
-                          SDL_Rect *update_rect ATTRIBUTE_UNUSED)
+void blocks_etc_set_color(magic_api *api ATTRIBUTE_UNUSED,
+                          int which ATTRIBUTE_UNUSED,
+                          SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                          SDL_Surface *last ATTRIBUTE_UNUSED,
+                          Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED,
+                          Uint8 b ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
@@ -461,9 +463,10 @@ Uint8 blocks_etc_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBU
     return 2;
 }
 
-void blocks_etc_set_size(magic_api *api ATTRIBUTE_UNUSED, int which, int mode ATTRIBUTE_UNUSED,
-                         SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size,
-                         SDL_Rect *update_rect ATTRIBUTE_UNUSED)
+void blocks_etc_set_size(magic_api *api ATTRIBUTE_UNUSED, int which,
+                         int mode ATTRIBUTE_UNUSED,
+                         SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                         SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   if (which == TOOL_BLOCKS)
     EFFECT_REZ = size * 4;
