@@ -75,8 +75,8 @@ void calligraphy_switchout(magic_api * api, int which, int mode, SDL_Surface * c
 int calligraphy_modes(magic_api * api, int which);
 Uint8 calligraphy_accepted_sizes(magic_api * api, int which, int mode);
 Uint8 calligraphy_default_size(magic_api * api, int which, int mode);
-void calligraphy_set_size(magic_api * api, int which, int mode, SDL_Surface * canvas, SDL_Surface * last, Uint8 size,
-                          SDL_Rect * update_rect);
+void calligraphy_set_size(magic_api * api, int which, int mode,
+                          SDL_Surface * canvas, SDL_Surface * last, Uint8 size, SDL_Rect * update_rect);
 
 
 
@@ -316,9 +316,10 @@ void calligraphy_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 }
 
 // We don't use colors
-void calligraphy_set_color(magic_api *api, int which ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED,
-                           SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r, Uint8 g, Uint8 b,
-                           SDL_Rect *update_rect ATTRIBUTE_UNUSED)
+void calligraphy_set_color(magic_api *api, int which ATTRIBUTE_UNUSED,
+                           SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                           SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r,
+                           Uint8 g, Uint8 b, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   int x, y;
   Uint8 a;
@@ -468,9 +469,11 @@ Uint8 calligraphy_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIB
   return 2;
 }
 
-void calligraphy_set_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                          SDL_Surface *canvas ATTRIBUTE_UNUSED, SDL_Surface *last ATTRIBUTE_UNUSED,
-                          Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
+void calligraphy_set_size(magic_api *api ATTRIBUTE_UNUSED,
+                          int which ATTRIBUTE_UNUSED,
+                          int mode ATTRIBUTE_UNUSED,
+                          SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                          SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   callig_size = size;
 }
