@@ -4,7 +4,7 @@
   Fade and Darken Magic Tools Plugin
   Tux Paint - A simple drawing program for children.
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 22, 2023
+  Last updated: January 16, 2024
 */
 
 #include <stdio.h>
@@ -52,6 +52,15 @@ char *tool_names[NUM_TOOLS] = {
   gettext_noop("Keep Color"),
 };
 
+int tool_orders[NUM_TOOLS] = {
+  301,
+  300,
+  201,
+  200,
+  401,
+  402,
+};
+
 char *tool_descriptions[NUM_TOOLS][2] = {
   {
    gettext_noop("Click and drag the mouse to lighten parts of your picture."),
@@ -107,11 +116,12 @@ static int fade_darken_radius = 16;
 
 /* Local function prototypes: */
 
-int fade_darken_init(magic_api * api, Uint32 disabled_features);
+int fade_darken_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 Uint32 fade_darken_api_version(void);
 int fade_darken_get_tool_count(magic_api * api);
 SDL_Surface *fade_darken_get_icon(magic_api * api, int which);
 int fade_darken_get_group(magic_api * api, int which);
+int fade_darken_get_order(int which);
 char *fade_darken_get_name(magic_api * api, int which);
 char *fade_darken_get_description(magic_api * api, int which, int mode);
 static void do_fade_darken(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y);
@@ -131,11 +141,11 @@ void fade_darken_switchout(magic_api * api, int which, int mode, SDL_Surface * c
 int fade_darken_modes(magic_api * api, int which);
 Uint8 fade_darken_accepted_sizes(magic_api * api, int which, int mode);
 Uint8 fade_darken_default_size(magic_api * api, int which, int mode);
-void fade_darken_set_size(magic_api * api, int which, int mode, SDL_Surface * canvas, SDL_Surface * last, Uint8 size,
-                          SDL_Rect * update_rect);
+void fade_darken_set_size(magic_api * api, int which, int mode,
+                          SDL_Surface * canvas, SDL_Surface * last, Uint8 size, SDL_Rect * update_rect);
 
 
-int fade_darken_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int fade_darken_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   int i;
   char fname[1024];
@@ -155,13 +165,13 @@ Uint32 fade_darken_api_version(void)
 }
 
 // Multiple tools:
-int fade_darken_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int fade_darken_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (NUM_TOOLS);
 }
 
 // Load our icon:
-SDL_Surface *fade_darken_get_icon(magic_api * api, int which)
+SDL_Surface *fade_darken_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -171,24 +181,30 @@ SDL_Surface *fade_darken_get_icon(magic_api * api, int which)
 }
 
 // Return our name, localized:
-char *fade_darken_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *fade_darken_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
   return strdup(gettext(tool_names[which]));
 }
 
 // Return our group (all the same):
-int fade_darken_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int fade_darken_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_COLOR_FILTERS;
 }
 
+// Return our order:
+int fade_darken_get_order(int which)
+{
+  return tool_orders[which];
+}
+
 // Return our description, localized:
-char *fade_darken_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
+char *fade_darken_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode)
 {
   return strdup(gettext(tool_descriptions[which][mode - 1]));
 }
 
-static void do_fade_darken(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_fade_darken(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   Uint8 r, g, b;
   magic_api *api = (magic_api *) ptr;
@@ -255,7 +271,7 @@ static void do_fade_darken(void *ptr, int which, SDL_Surface * canvas, SDL_Surfa
 
 
 // Callback that does the fade_darken color effect on a circle centered around x,y
-static void do_fade_darken_paint(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_fade_darken_paint(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   int xx, yy;
   magic_api *api = (magic_api *) ptr;
@@ -273,8 +289,8 @@ static void do_fade_darken_paint(void *ptr, int which, SDL_Surface * canvas, SDL
 }
 
 // Ask Tux Paint to call our 'do_fade_darken_paint()' callback over a line
-void fade_darken_drag(magic_api * api, int which, SDL_Surface * canvas,
-                      SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void fade_darken_drag(magic_api *api, int which, SDL_Surface *canvas,
+                      SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
   SDL_LockSurface(last);
   SDL_LockSurface(canvas);
@@ -309,8 +325,8 @@ void fade_darken_drag(magic_api * api, int which, SDL_Surface * canvas,
 
 // Ask Tux Paint to call our 'do_fade_darken_paint()' callback at a single point,
 // or 'do_fade_darken()' on the entire image
-void fade_darken_click(magic_api * api, int which, int mode,
-                       SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void fade_darken_click(magic_api *api, int which, int mode,
+                       SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_PAINT)
     fade_darken_drag(api, which, canvas, last, x, y, x, y, update_rect);
@@ -332,17 +348,17 @@ void fade_darken_click(magic_api * api, int which, int mode,
 }
 
 // Release
-void fade_darken_release(magic_api * api ATTRIBUTE_UNUSED,
+void fade_darken_release(magic_api *api ATTRIBUTE_UNUSED,
                          int which ATTRIBUTE_UNUSED,
-                         SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                         SDL_Surface * last ATTRIBUTE_UNUSED,
-                         int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                         SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                         SDL_Surface *last ATTRIBUTE_UNUSED,
+                         int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 
 // No setup happened:
-void fade_darken_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void fade_darken_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   if (snd_effects[0] != NULL)
     Mix_FreeChunk(snd_effects[0]);
@@ -350,9 +366,10 @@ void fade_darken_shutdown(magic_api * api ATTRIBUTE_UNUSED)
     Mix_FreeChunk(snd_effects[1]);
 }
 
-void fade_darken_set_color(magic_api * api, int which ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                           SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 r, Uint8 g, Uint8 b,
-                           SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void fade_darken_set_color(magic_api *api, int which ATTRIBUTE_UNUSED,
+                           SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                           SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r,
+                           Uint8 g, Uint8 b, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   float tmp;
 
@@ -360,7 +377,7 @@ void fade_darken_set_color(magic_api * api, int which ATTRIBUTE_UNUSED, SDL_Surf
 }
 
 // We don't use colors
-int fade_darken_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int fade_darken_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   if (which == TOOL_REMOVE || which == TOOL_KEEP)
     return 1;
@@ -368,24 +385,23 @@ int fade_darken_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTR
   return 0;
 }
 
-void fade_darken_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                          int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void fade_darken_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                          int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void fade_darken_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                           int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void fade_darken_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                           int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int fade_darken_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int fade_darken_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_PAINT | MODE_FULLSCREEN);
 }
 
 
-Uint8 fade_darken_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                                 int mode ATTRIBUTE_UNUSED)
+Uint8 fade_darken_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   if (mode == MODE_PAINT)
     return 8;
@@ -393,14 +409,16 @@ Uint8 fade_darken_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATT
     return 0;
 }
 
-Uint8 fade_darken_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 fade_darken_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void fade_darken_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                          SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 size,
-                          SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void fade_darken_set_size(magic_api *api ATTRIBUTE_UNUSED,
+                          int which ATTRIBUTE_UNUSED,
+                          int mode ATTRIBUTE_UNUSED,
+                          SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                          SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   fade_darken_radius = size * 4;
 }
