@@ -6,7 +6,7 @@
 
   Credits: Andrew Corcoran <akanewbie@gmail.com>
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -25,7 +25,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 19, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -71,6 +71,12 @@ const char *sharpen_icon_filenames[sharpen_NUM_TOOLS] = {
   "silhouette.png"
 };
 
+int sharpen_orders[sharpen_NUM_TOOLS] = {
+  300,
+  2,
+  302,
+};
+
 const char *sharpen_names[sharpen_NUM_TOOLS] = {
   gettext_noop("Edges"),
   gettext_noop("Sharpen"),
@@ -87,11 +93,12 @@ const char *sharpen_descs[sharpen_NUM_TOOLS][2] = {
 };
 
 Uint32 sharpen_api_version(void);
-int sharpen_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED);
+int sharpen_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 int sharpen_get_tool_count(magic_api * api);
 SDL_Surface *sharpen_get_icon(magic_api * api, int which);
 char *sharpen_get_name(magic_api * api, int which);
 int sharpen_get_group(magic_api * api, int which);
+int sharpen_get_order(int which);
 char *sharpen_get_description(magic_api * api, int which, int mode);
 static int sharpen_grey(Uint8 r1, Uint8 g1, Uint8 b1);
 static void do_sharpen_pixel(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y);
@@ -114,8 +121,8 @@ void sharpen_switchout(magic_api * api, int which, int mode, SDL_Surface * canva
 int sharpen_modes(magic_api * api, int which);
 Uint8 sharpen_accepted_sizes(magic_api * api, int which, int mode);
 Uint8 sharpen_default_size(magic_api * api, int which, int mode);
-void sharpen_set_size(magic_api * api, int which, int mode, SDL_Surface * canvas, SDL_Surface * last, Uint8 size,
-                      SDL_Rect * update_rect);
+void sharpen_set_size(magic_api * api, int which, int mode,
+                      SDL_Surface * canvas, SDL_Surface * last, Uint8 size, SDL_Rect * update_rect);
 
 
 
@@ -126,7 +133,7 @@ Uint32 sharpen_api_version(void)
 
 
 // No setup required:
-int sharpen_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int sharpen_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
 
   int i;
@@ -142,13 +149,13 @@ int sharpen_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
 }
 
 // We have multiple tools:
-int sharpen_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int sharpen_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (sharpen_NUM_TOOLS);
 }
 
 // Load our icons:
-SDL_Surface *sharpen_get_icon(magic_api * api, int which)
+SDL_Surface *sharpen_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -157,21 +164,27 @@ SDL_Surface *sharpen_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char *sharpen_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *sharpen_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
-  return (strdup(gettext_noop(sharpen_names[which])));
+  return (strdup(gettext(sharpen_names[which])));
 }
 
 // Return our group (all the same):
-int sharpen_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int sharpen_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_DISTORTS;
 }
 
-// Return our descriptions, localized:
-char *sharpen_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
+// Return our order 
+int sharpen_get_order(int which)
 {
-  return (strdup(gettext_noop(sharpen_descs[which][mode - 1])));
+  return sharpen_orders[which];
+}
+
+// Return our descriptions, localized:
+char *sharpen_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode)
+{
+  return (strdup(gettext(sharpen_descs[which][mode - 1])));
 }
 
 //Calculates the grey scale value for a rgb pixel
@@ -181,7 +194,7 @@ static int sharpen_grey(Uint8 r1, Uint8 g1, Uint8 b1)
 }
 
 // Do the effect:
-static void do_sharpen_pixel(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_sharpen_pixel(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   magic_api *api = (magic_api *) ptr;
 
@@ -243,7 +256,7 @@ static void do_sharpen_pixel(void *ptr, int which, SDL_Surface * canvas, SDL_Sur
 }
 
 // Do the effect for the full image
-static void do_sharpen_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, int which)
+static void do_sharpen_full(void *ptr, SDL_Surface *canvas, SDL_Surface *last, int which)
 {
   magic_api *api = (magic_api *) ptr;
 
@@ -264,7 +277,7 @@ static void do_sharpen_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last,
 }
 
 //do the effect for the brush
-static void do_sharpen_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_sharpen_brush(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   int xx, yy;
   magic_api *api = (magic_api *) ptr;
@@ -282,8 +295,8 @@ static void do_sharpen_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Sur
 }
 
 // Affect the canvas on drag:
-void sharpen_drag(magic_api * api, int which, SDL_Surface * canvas,
-                  SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void sharpen_drag(magic_api *api, int which, SDL_Surface *canvas,
+                  SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
 
   api->line((void *)api, which, canvas, last, ox, oy, x, y, 1, do_sharpen_brush);
@@ -312,8 +325,8 @@ void sharpen_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void sharpen_click(magic_api * api, int which, int mode,
-                   SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void sharpen_click(magic_api *api, int which, int mode,
+                   SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_PAINT)
     sharpen_drag(api, which, canvas, last, x, y, x, y, update_rect);
@@ -329,16 +342,16 @@ void sharpen_click(magic_api * api, int which, int mode,
 }
 
 // Affect the canvas on release:
-void sharpen_release(magic_api * api ATTRIBUTE_UNUSED,
+void sharpen_release(magic_api *api ATTRIBUTE_UNUSED,
                      int which ATTRIBUTE_UNUSED,
-                     SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                     SDL_Surface * last ATTRIBUTE_UNUSED,
-                     int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                     SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                     SDL_Surface *last ATTRIBUTE_UNUSED,
+                     int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // No setup happened:
-void sharpen_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void sharpen_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   //Clean up sounds
   int i;
@@ -353,37 +366,39 @@ void sharpen_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 }
 
 // Record the color from Tux Paint:
-void sharpen_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
-                       SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
-                       Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED,
-                       SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void sharpen_set_color(magic_api *api ATTRIBUTE_UNUSED,
+                       int which ATTRIBUTE_UNUSED,
+                       SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                       SDL_Surface *last ATTRIBUTE_UNUSED,
+                       Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED,
+                       Uint8 b ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // Use colors:
-int sharpen_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int sharpen_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void sharpen_switchin(magic_api * api ATTRIBUTE_UNUSED,
-                      int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void sharpen_switchin(magic_api *api ATTRIBUTE_UNUSED,
+                      int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void sharpen_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                       int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void sharpen_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                       int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int sharpen_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int sharpen_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_FULLSCREEN | MODE_PAINT);
 }
 
 
 
-Uint8 sharpen_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 sharpen_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   if (mode == MODE_PAINT)
     return 8;
@@ -391,14 +406,15 @@ Uint8 sharpen_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBU
     return 0;
 }
 
-Uint8 sharpen_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 sharpen_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void sharpen_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                      SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 size,
-                      SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void sharpen_set_size(magic_api *api ATTRIBUTE_UNUSED,
+                      int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                      SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                      SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   sharpen_RADIUS = size * 4;
 }
