@@ -10,7 +10,7 @@
 
   Credits: Andrew Corcoran <akanewbie@gmail.com>
 
-  Copyright (c) 2002-2023 by Bill Kendrick and others; see AUTHORS.txt
+  Copyright (c) 2002-2024 by Bill Kendrick and others; see AUTHORS.txt
   bill@newbreedsoftware.com
   https://tuxpaint.org/
 
@@ -29,7 +29,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  Last updated: April 22, 2023
+  Last updated: October 7, 2024
 */
 
 #include <stdio.h>
@@ -74,6 +74,11 @@ const char *tint_names[tint_NUM_TOOLS] = {
   gettext_noop("Color & White") // It does more than this but more intuitive than threshold.
 };
 
+const int tint_orders[tint_NUM_TOOLS] = {
+  500,
+  501,
+};
+
 const char *tint_descs[tint_NUM_TOOLS][2] = {
   {gettext_noop("Click and drag the mouse around to change the color of parts of your picture."),
    gettext_noop("Click to change the color of your entire picture."),},
@@ -81,12 +86,13 @@ const char *tint_descs[tint_NUM_TOOLS][2] = {
    gettext_noop("Click to turn your entire picture into white and a color you choose.")}
 };
 
-int tint_init(magic_api * api, Uint32 disabled_features);
+int tint_init(magic_api * api, Uint8 disabled_features, Uint8 complexity_level);
 Uint32 tint_api_version(void);
 int tint_get_tool_count(magic_api * api);
 SDL_Surface *tint_get_icon(magic_api * api, int which);
 char *tint_get_name(magic_api * api, int which);
 int tint_get_group(magic_api * api, int which);
+int tint_get_order(int which);
 char *tint_get_description(magic_api * api, int which, int mode);
 static int tint_grey(Uint8 r1, Uint8 g1, Uint8 b1);
 static void do_tint_pixel(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y);
@@ -107,8 +113,8 @@ void tint_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas);
 int tint_modes(magic_api * api, int which);
 Uint8 tint_accepted_sizes(magic_api * api, int which, int mode);
 Uint8 tint_default_size(magic_api * api, int which, int mode);
-void tint_set_size(magic_api * api, int which, int mode, SDL_Surface * canvas, SDL_Surface * last, Uint8 size,
-                   SDL_Rect * update_rect);
+void tint_set_size(magic_api * api, int which, int mode, SDL_Surface * canvas,
+                   SDL_Surface * last, Uint8 size, SDL_Rect * update_rect);
 
 
 Uint32 tint_api_version(void)
@@ -117,7 +123,7 @@ Uint32 tint_api_version(void)
 }
 
 //Load sounds
-int tint_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
+int tint_init(magic_api *api, Uint8 disabled_features ATTRIBUTE_UNUSED, Uint8 complexity_level ATTRIBUTE_UNUSED)
 {
   int i;
   char fname[1024];
@@ -130,13 +136,13 @@ int tint_init(magic_api * api, Uint32 disabled_features ATTRIBUTE_UNUSED)
   return (1);
 }
 
-int tint_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
+int tint_get_tool_count(magic_api *api ATTRIBUTE_UNUSED)
 {
   return (tint_NUM_TOOLS);
 }
 
 // Load our icons:
-SDL_Surface *tint_get_icon(magic_api * api, int which)
+SDL_Surface *tint_get_icon(magic_api *api, int which)
 {
   char fname[1024];
 
@@ -145,21 +151,27 @@ SDL_Surface *tint_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char *tint_get_name(magic_api * api ATTRIBUTE_UNUSED, int which)
+char *tint_get_name(magic_api *api ATTRIBUTE_UNUSED, int which)
 {
-  return (strdup(gettext_noop(tint_names[which])));
+  return (strdup(gettext(tint_names[which])));
 }
 
 // Return our group (both the same):
-int tint_get_group(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int tint_get_group(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return MAGIC_TYPE_COLOR_FILTERS;
 }
 
-// Return our descriptions, localized:
-char *tint_get_description(magic_api * api ATTRIBUTE_UNUSED, int which, int mode)
+// Return our order:
+int tint_get_order(int which)
 {
-  return (strdup(gettext_noop(tint_descs[which][mode - 1])));
+  return tint_orders[which];
+}
+
+// Return our descriptions, localized:
+char *tint_get_description(magic_api *api ATTRIBUTE_UNUSED, int which, int mode)
+{
+  return (strdup(gettext(tint_descs[which][mode - 1])));
 }
 
 //Calculates the grey scale value for a rgb pixel
@@ -168,7 +180,7 @@ static int tint_grey(Uint8 r1, Uint8 g1, Uint8 b1)
   return 0.3 * r1 + .59 * g1 + 0.11 * b1;
 }
 
-static void do_tint_pixel(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_tint_pixel(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
 
   magic_api *api = (magic_api *) ptr;
@@ -203,7 +215,7 @@ static void do_tint_pixel(void *ptr, int which, SDL_Surface * canvas, SDL_Surfac
 }
 
 // Do the effect:
-static void do_tint_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, int which)
+static void do_tint_full(void *ptr, SDL_Surface *canvas, SDL_Surface *last, int which)
 {
   int x, y;
 
@@ -216,7 +228,7 @@ static void do_tint_full(void *ptr, SDL_Surface * canvas, SDL_Surface * last, in
   }
 }
 
-static void do_tint_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surface * last, int x, int y)
+static void do_tint_brush(void *ptr, int which, SDL_Surface *canvas, SDL_Surface *last, int x, int y)
 {
   int xx, yy;
   magic_api *api = (magic_api *) ptr;
@@ -234,8 +246,8 @@ static void do_tint_brush(void *ptr, int which, SDL_Surface * canvas, SDL_Surfac
 }
 
 // Affect the canvas on drag:
-void tint_drag(magic_api * api, int which, SDL_Surface * canvas,
-               SDL_Surface * last, int ox, int oy, int x, int y, SDL_Rect * update_rect)
+void tint_drag(magic_api *api, int which, SDL_Surface *canvas,
+               SDL_Surface *last, int ox, int oy, int x, int y, SDL_Rect *update_rect)
 {
 
   api->line((void *)api, which, canvas, last, ox, oy, x, y, 1, do_tint_brush);
@@ -264,8 +276,8 @@ void tint_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void tint_click(magic_api * api, int which, int mode,
-                SDL_Surface * canvas, SDL_Surface * last, int x, int y, SDL_Rect * update_rect)
+void tint_click(magic_api *api, int which, int mode,
+                SDL_Surface *canvas, SDL_Surface *last, int x, int y, SDL_Rect *update_rect)
 {
   if (mode == MODE_PAINT)
     tint_drag(api, which, canvas, last, x, y, x, y, update_rect);
@@ -281,16 +293,16 @@ void tint_click(magic_api * api, int which, int mode,
 }
 
 // Affect the canvas on release:
-void tint_release(magic_api * api ATTRIBUTE_UNUSED,
+void tint_release(magic_api *api ATTRIBUTE_UNUSED,
                   int which ATTRIBUTE_UNUSED,
-                  SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                  SDL_Surface * last ATTRIBUTE_UNUSED, int x ATTRIBUTE_UNUSED,
-                  int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+                  SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                  SDL_Surface *last ATTRIBUTE_UNUSED, int x ATTRIBUTE_UNUSED,
+                  int y ATTRIBUTE_UNUSED, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // No setup happened:
-void tint_shutdown(magic_api * api ATTRIBUTE_UNUSED)
+void tint_shutdown(magic_api *api ATTRIBUTE_UNUSED)
 {
   //Clean up sounds
   int i;
@@ -305,9 +317,11 @@ void tint_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 }
 
 // Record the color from Tux Paint:
-void tint_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED,
-                    SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 r, Uint8 g, Uint8 b,
-                    SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void tint_set_color(magic_api *api ATTRIBUTE_UNUSED,
+                    int which ATTRIBUTE_UNUSED,
+                    SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                    SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 r, Uint8 g,
+                    Uint8 b, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   tint_r = r;
   tint_g = g;
@@ -315,12 +329,12 @@ void tint_set_color(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED
 }
 
 // Use colors:
-int tint_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int tint_requires_colors(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 1;
 }
 
-void tint_switchin(magic_api * api, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas)
+void tint_switchin(magic_api *api, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas)
 {
 
   int x, y;
@@ -347,18 +361,18 @@ void tint_switchin(magic_api * api, int which ATTRIBUTE_UNUSED, int mode ATTRIBU
   }
 }
 
-void tint_switchout(magic_api * api ATTRIBUTE_UNUSED,
-                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
+void tint_switchout(magic_api *api ATTRIBUTE_UNUSED,
+                    int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface *canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int tint_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
+int tint_modes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return (MODE_FULLSCREEN | MODE_PAINT);
 }
 
 
-Uint8 tint_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 tint_accepted_sizes(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   if (mode == MODE_PAINT)
     return 8;
@@ -366,14 +380,15 @@ Uint8 tint_accepted_sizes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_
     return 0;
 }
 
-Uint8 tint_default_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
+Uint8 tint_default_size(magic_api *api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return 4;
 }
 
-void tint_set_size(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
-                   SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED, Uint8 size,
-                   SDL_Rect * update_rect ATTRIBUTE_UNUSED)
+void tint_set_size(magic_api *api ATTRIBUTE_UNUSED,
+                   int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED,
+                   SDL_Surface *canvas ATTRIBUTE_UNUSED,
+                   SDL_Surface *last ATTRIBUTE_UNUSED, Uint8 size, SDL_Rect *update_rect ATTRIBUTE_UNUSED)
 {
   tint_RADIUS = size * 4;
 }
