@@ -1,8 +1,8 @@
 /*
   get_fname.c
 
-  Copyright (c) 2009 - 2021
-  http://www.tuxpaint.org/
+  Copyright (c) 2009 - 2024
+  https://tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,6 +19,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
+  Last updated: October 20, 2024
+
   $Id$
 */
 
@@ -86,36 +88,47 @@ const char *exportdir;
 char *get_fname(const char *const name, int kind)
 {
   char f[512];
-  // const char *restrict const dir;
-  const char * dir;
 
-  if (kind == DIR_SAVE) {
+  // const char *restrict const dir;
+  const char *dir;
+
+  if (kind == DIR_SAVE)
+  {
     dir = savedir;
-  } else if (kind == DIR_DATA) {
+  }
+  else if (kind == DIR_DATA)
+  {
     dir = datadir;
-  } else if (kind == DIR_EXPORT || kind == DIR_EXPORT_PARENT) {
+  }
+  else if (kind == DIR_EXPORT || kind == DIR_EXPORT_PARENT)
+  {
     dir = exportdir;
   }
+  else
+  {
+    /* Last resort! */
+    dir = "";
+  }
 
-  snprintf(f, sizeof(f),
-           "%s%c%s",
-	   dir, (*name) ? '/' : '\0', /* Some mkdir()'s don't like trailing slashes */
-	   name);
+  snprintf(f, sizeof(f), "%s%c%s", dir, (*name) ? '/' : '\0',   /* Some mkdir()'s don't like trailing slashes */
+           name);
 
-  if (kind == DIR_EXPORT_PARENT) {
+  if (kind == DIR_EXPORT_PARENT)
+  {
     int len, i, stop;
 
     stop = -1;
     len = strlen(f);
-    for (i = len - 1; i >= 0 && stop == -1; i--) {
+    for (i = len - 1; i >= 0 && stop == -1; i--)
+    {
       if (f[i] == '/')
         stop = i;
     }
-    if (stop != -1) {
+    if (stop != -1)
+    {
       f[stop] = '\0';
     }
   }
 
   return strdup(f);
 }
-
