@@ -1,8 +1,8 @@
 /*
   get_fname.h
 
-  Copyright (c) 2009
-  http://www.tuxpaint.org/
+  Copyright (c) 2009-2023
+  https://tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id$
+  Last modified: June 8, 2023
 */
 
 #ifndef GET_FNAME_H
@@ -27,14 +27,21 @@
 
 extern const char *savedir;
 extern const char *datadir;
+extern const char *exportdir;
 
 enum
 {
+  /* (See get_fname.c for details) */
   DIR_SAVE,
-  DIR_DATA
+  DIR_DATA,
+  DIR_EXPORT,
+  DIR_EXPORT_PARENT
 };
 
 char *get_fname(const char *const name, int kind);
 
+/* Prefix for templates exported within Tux Paint (via Open dialog),
+   so we can delete them (via New dialog) */
+#define EXPORTED_TEMPLATE_PREFIX "exported"
 
 #endif
