@@ -23,7 +23,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  June 14, 2002 - April 30, 2023
+  June 14, 2002 - June 2, 2024
 */
 
 
@@ -185,7 +185,6 @@ typedef struct language_to_locale_struct
 extern const char *lang_prefixes[NUM_LANGS];
 extern int need_own_font;
 extern int need_right_to_left;  // Right-justify
-extern int need_right_to_left_word;     // Words need to be reversed, too! (e.g., Hebrew, but not Arabic)
 extern const char *lang_prefix, *short_lang_prefix;
 
 typedef struct w_langs
@@ -193,7 +192,6 @@ typedef struct w_langs
   int langint;
   int need_own_font;
   int need_right_to_left;
-  int need_right_to_left_word;
   int lang_y_nudge;
   const char *lang_prefix;
   const char *short_lang_prefix;
@@ -204,7 +202,7 @@ extern w_langs wished_langs[255];
 /* Function prototypes: */
 
 int get_current_language(void);
-int setup_i18n(const char *restrict lang, const char *restrict locale, int *ptr_num_wished_languages) MUST_CHECK;
-     void mysetenv(const char *name, const char *value);
+void setup_i18n(const char *restrict lang, const char *restrict locale, int *ptr_num_wished_languages);
+void mysetenv(const char *name, const char *value);
 
 #endif
