@@ -1,7 +1,7 @@
 /* playsound.h
 
-  Copyright (c) 2002-2009
-  http://www.tuxpaint.org/
+  Copyright (c) 2002-2022
+  https://tuxpaint.org/
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
+  Last updated: December 11, 2022
   $Id$
 */
 
@@ -35,7 +36,7 @@
 #define SNDDIST_NEAR -999
 
 extern Mix_Chunk *sounds[NUM_SOUNDS];
-extern int mute, use_sound;
+extern int mute, use_sound, use_stereo;
 
 void playsound(SDL_Surface * screen, int chan, int s, int override, int x, int y);
 
